@@ -344,9 +344,6 @@ class E2ECertificateManager(object):
 
         # api instance prepare
         import volcenginesdkcore
-        self._api_instance_enabled = True
-        if ak is None or sk is None:
-            self._api_instance_enabled = False
         configuration = volcenginesdkcore.Configuration()
         configuration.ak = ak
         configuration.sk = sk
@@ -359,11 +356,14 @@ class E2ECertificateManager(object):
         self.cert_path = os.environ.get("E2E_CERTIFICATE_PATH")
 
         # ark client prepare
-        self.client = Ark(
-            base_url=base_url,
-            api_key=api_key,
-            ak=ak, sk=sk,
-        )
+        self._ark_client_enabled = True
+        if api_key is None:
+            self._ark_client_enabled = False
+        else:
+            self.client = Ark(
+                base_url=base_url,
+                api_key=api_key,
+            )
         self._e2e_uri = "/e2e/get/certificate"
         self._x_session_token = {'X-Session-Token': self._e2e_uri}
 
@@ -425,10 +425,10 @@ class E2ECertificateManager(object):
             if cert_pem is None:
                 if self.cert_path is not None:
                     cert_pem = self._load_cert_by_cert_path()
-                elif self._api_instance_enabled:
-                    cert_pem = self._load_cert_by_ak_sk(ep)
-                else:
+                elif self._ark_client_enabled:
                     cert_pem = self._sync_load_cert_by_auth(ep)
+                else:
+                    cert_pem = self._load_cert_by_ak_sk(ep)
                 self._save_cert_to_file(ep, cert_pem)
             self._certificate_manager[ep] = key_agreement_client(
                 certificate_pem_string=cert_pem
