@@ -1,6 +1,6 @@
 from __future__ import annotations
 
-from typing import Union, Iterable
+from typing import Union, Iterable, Optional
 from typing_extensions import Literal, Required, TypedDict
 
 from .chat_completion_content_part_param import ChatCompletionContentPartParam
@@ -14,3 +14,10 @@ class ChatCompletionUserMessageParam(TypedDict, total=False):
 
     role: Required[Literal["user"]]
     """The role of the messages author, in this case `user`."""
+
+    name: Optional[str]
+    """An optional name for the participant.
+
+    Provides the model information to differentiate between participants of the same
+    role.
+    """
